@@ -477,7 +477,7 @@ BOOL CALLBACK GPUinit()
  GPUIsIdle;
  GPUIsReadyForCommands;
 
- return GPUopen(NULL, "PSX4M", "");
+ return GPUopen(NULL, "pete gui", "");
 }                             
 
 ////////////////////////////////////////////////////////////////////////
