@@ -37,8 +37,11 @@ int OpenPlugins(void)
 	ret = SPU_open();
 	if (ret < 0) { SysPrintf("Error Opening SPU Component"); return -1; }
 	// EDIT SPU_registerCallback(SPUirq);
-  //ret = GPU_open(0);
-	//if (ret < 0) { SysPrintf("Error Opening GPU Component"); return -1; }
+	/*#ifdef PEOPS_GPU
+    ret = GPU_open(0);
+	if (ret < 0) { SysPrintf("Error Opening GPU Component"); return -1; }
+	#endif*/
+	
 	ret = PAD1_open();
 	if (ret < 0) { SysPrintf("Error Opening PAD1 Component"); return -1; }
 	ret = PAD2_open();
